@@ -15,26 +15,57 @@
 """
 Processors and tools specific to the `Twisted <http://twistedmatrix.com/>`_
 networking engine.
+
+See also :doc:`structlog's Twisted support <twisted>`.
 """
 
 from __future__ import absolute_import, division, print_function
 
-import sys
 import json
+import sys
 
 from twisted.python.failure import Failure
+from twisted.python import log
 from twisted.python.log import ILogObserver, textFromEventDict
 from zope.interface import implementer
 
-from structlog._compat import string_types
+from structlog._base import BoundLoggerBase
+from structlog._compat import PY2, string_types
 from structlog._utils import until_not_interrupted
 from structlog.processors import (
     KeyValueRenderer,
-    # can't import processors module because of circular imports
-    JSONRenderer as _JSONRenderer
+    # can't import processors module without risking circular imports
+    JSONRenderer as GenericJSONRenderer
 )
 
 
+class BoundLogger(BoundLoggerBase):
+    """
+    Twisted-specific version of :class:`structlog.BoundLogger`.
+
+    Works exactly like the generic one except that it takes advantage of
+    knowing the logging methods in advance.
+
+    Use it like::
+
+        configure(
+            wrapper_class=structlog.twisted.BoundLogger,
+        )
+
+    """
+    def msg(self, event=None, **kw):
+        """
+        Process event and call ``log.msg()`` with the result.
+        """
+        return self._proxy_to_logger('msg', event, **kw)
+
+    def err(self, event=None, **kw):
+        """
+        Process event and call ``log.err()`` with the result.
+        """
+        return self._proxy_to_logger('err', event, **kw)
+
+
 class LoggerFactory(object):
     """
     Build a Twisted logger when an *instance* is called.
@@ -47,7 +78,6 @@ class LoggerFactory(object):
         """
         :rvalue: A new Twisted logger.
         """
-        from twisted.python import log
         return log
 
 
@@ -84,11 +114,12 @@ def _extractStuffAndWhy(eventDict):
     # formatting.  Avoid log.err() to dump another traceback into the log.
     if isinstance(_stuff, BaseException):
         _stuff = Failure(_stuff)
-    sys.exc_clear()
+    if PY2:
+        sys.exc_clear()
     return _stuff, _why, eventDict
 
 
-class JSONRenderer(_JSONRenderer):
+class JSONRenderer(GenericJSONRenderer):
     """
     Behaves like :class:`structlog.processors.JSONRenderer` except that it
     formats tracebacks and failures itself if called with `err()`.
@@ -96,8 +127,8 @@ class JSONRenderer(_JSONRenderer):
     *Not* an adapter like :class:`EventAdapter` but a real formatter.  Nor does
     it require to be adapted using it.
 
-    Use together with a :func:`withJSONObserver`-wrapped Twisted logger like
-    :func:`plainJSONStdOutLogger` for pure-JSON logs.
+    Use together with a :class:`JSONLogObserverWrapper`-wrapped Twisted logger
+    like :func:`plainJSONStdOutLogger` for pure-JSON logs.
     """
     def __call__(self, logger, name, eventDict):
         _stuff, _why, eventDict = _extractStuffAndWhy(eventDict)
@@ -108,7 +139,7 @@ class JSONRenderer(_JSONRenderer):
                 _stuff.cleanFailure()
         else:
             eventDict['event'] = _why
-        return ((_JSONRenderer.__call__(self, logger, name, eventDict),),
+        return ((GenericJSONRenderer.__call__(self, logger, name, eventDict),),
                 {'_structlog': True})
 
 
